package labyrinth.menu;

import java.io.IOException;

import javax.microedition.lcdui.Font;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;

import labyrinth.Labyrinth;
import labyrinth.game.Game;
import labyrinth.game.GameScreen;
import labyrinth.settings.GameSettings;
import labyrinth.settings.SoundNokia;

import com.nokia.mid.ui.FullCanvas;

/*
 * LabyrinthMenu  a classe que contm o menu principal do jogo, bem como
 * algumas telas de informao e configurao. Essa classe posibilitar ao
 * usurio acesso ao jogo, configuraes do jogo, visualizaes de telas de
 * ajuda e informaes. A classe LabyrinthMenu estende da classe List e
 * implementa a classe CommandListener.
 */
public class LabyrinthMenu extends FullCanvas {

	/**
	 * atributo que armazena o MIDlet ativo do jogo.
	 */
	private Labyrinth main;

	/**
	 * Atributo que contem uma imagem a ser impressa.
	 */
	private Image fundo;

	/**
	 * Atributo que contem uma imagem a ser impressa.
	 */
	private Image botao;

	/**
	 *  
	 */
	private int cursor;

	private GameSettings gs;
	
	

	/**
	 * Contrutor da classe que inicializa os atributos, bem como gera a lista de
	 * opes do menu.
	 * 
	 * @param main
	 *            Objeto do tipo Labyrinth que representar o MIDlet ativo do
	 *            jogo.
	 */
	public LabyrinthMenu(Labyrinth main) {
		
		
		this.gs = new GameSettings();

		this.main = main;

		this.cursor = 53;

		fundo = null;
		botao = null;

		repaint();

	}

	/**
	 *  
	 */
	protected void paint(Graphics graphics) {
		graphics.setColor(0, 0, 0);

		try {
			//Pinta o fundo e o cursor
			this.fundo = Image.createImage("/labyrinth/images/settings.png");
		} catch (IOException e) {

			e.printStackTrace();
		}
		graphics.drawImage(this.fundo, 0, 0, Graphics.LEFT | Graphics.TOP);
		this.fundo = null;
		System.gc();
		try {
			this.botao = Image.createImage("/labyrinth/images/sprite.png");
		} catch (IOException e1) {

			e1.printStackTrace();
		}
		graphics.drawImage(this.botao, 46, this.cursor, Graphics.LEFT
				| Graphics.TOP);
		this.botao = null;
		System.gc();

		//imprime o Titulo
		graphics.setFont(Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_PLAIN,
				Font.SIZE_LARGE));
		graphics.drawString("Labyrinth", 64, 25, Graphics.TOP
				| Graphics.HCENTER);

		//imprime as opcoes
		graphics.setFont(Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_PLAIN,
				Font.SIZE_SMALL));
		graphics.drawString("Play", 58, 52, 0);
		if (this.gs.getOption() == 1) {
			graphics.drawString("Continue", 58, 64, 0);
			graphics.drawString("Settings", 58, 76, 0);
			graphics.drawString("Help", 58, 88, 0);
			graphics.drawString("Records", 58, 100, 0);
			graphics.drawString("Credits", 58, 112, 0);
		} else {
			graphics.drawString("Settings", 58, 64, 0);
			graphics.drawString("Help", 58, 76, 0);
			graphics.drawString("Records", 58, 88, 0);
			graphics.drawString("Credits", 58, 100, 0);
		}
		
		graphics.setColor(0,0,0);			
		graphics.drawString("exit", 108, 118, 0);
		graphics.drawString("select", 2, 118, 0);

	}

	/**
	 * Metodo que captura as teclas de movimentacao
	 */
	/*public void keyRepeated(int keyCode) {

		int key = getGameAction(keyCode);

		switch (key) {
		case UP:
			// MOVER O CURSOR PARA CIMA
			if (this.cursor == 53)
				this.cursor = 113;
			else
				this.cursor = this.cursor - 12;
			repaint();

			break;
		case DOWN:
			//MOVER O CURSOR PARA BAIXO
			if (this.cursor == 113)
				this.cursor = 53;
			else
				this.cursor = this.cursor + 12;

			repaint();

			break;
		default:

			break;

		}

	}*/

	/**
	 * Metodo que captura as teclas de movimentacao
	 */
	public void keyPressed(int keyCode) {

		int key = getGameAction(keyCode);

		switch (key) {
		case UP:
			// MOVER O CURSOR PARA CIMA
			if (this.cursor == 53) {
				if (this.gs.getOption() == 0) {
					this.cursor = 101;
				} else {
					this.cursor = 113;
				}
			} else{
				this.cursor = this.cursor - 12;
			}
			if(this.gs.getSound()){
				SoundNokia sound = new SoundNokia(523, 10);
				sound.run();
			}
			repaint();

			break;
		case DOWN:
			//MOVER O CURSOR PARA BAIXO
			if (this.gs.getOption() == 1 && this.cursor == 113) {
				this.cursor = 53;				
			} else if (this.gs.getOption() == 0 && this.cursor == 101) {
				this.cursor = 53;				
			} else{
				this.cursor = this.cursor + 12;
			}
			
			if(this.gs.getSound()){
				SoundNokia sound = new SoundNokia(523, 10);
				sound.run();
			}
			repaint();
			break;
		default:

			break;

		}

	}

	/**
	 * Metodo que captura as SoftKeys
	 */
	public void keyReleased(int keyRelease) {		
		switch (keyRelease) {
		case KEY_SOFTKEY1:
			//entrar na opcao
			this.selected();
			break;
		case KEY_SOFTKEY2:
			//Sair
			this.main.save = false;
			this.main.ScreenExit();
			break;
		case KEY_SEND:
			//send

			break;
		case KEY_END:
			//END
			this.main.save = false;
			this.main.ScreenExit();
			break;
		default:

			break;

		}
	}

	/**
	 * Mtodo que verifica qual a opo do menu foi selecionada.
	 */
	public void selected() {
		Runtime.getRuntime().gc();
		if (this.gs.getOption() == 1) {
			switch (this.cursor) {

			case 53:
				//Play
				this.play();

				break;
			case 65:
				//Continue
				this.continuing();
				break;
			case 77:
				//Settings
				this.showSettingsScreen();

				break;
			case 89:
				//Help
				this.showHelpScreen();

				break;
			case 101:
				//records
				this.showRecordsScreen();

				break;
			case 113:
				//Credits
				this.showCreditsScreen();

				break;
			default:

				break;
			}
		} else {
			switch (this.cursor) {
			case 53:
				//Play
				this.play();

				break;
			case 65:
				//Settings
				this.showSettingsScreen();
				break;
			case 77:
				//Help
				this.showHelpScreen();

				break;
			case 89:
				//records
				this.showRecordsScreen();

				break;
			case 101:
				//Credits
				this.showCreditsScreen();

				break;
			default:

				break;
			}
		}
		Runtime.getRuntime().gc();
	}

	/**
	 * Mtodo que inicia um novo jogo.
	 */
	public void play() {
		GameScreen game = new GameScreen(this);
		//this.main.setGameScreen(game);
		this.main.getDisplay().setCurrent(game);
	}

	/* ****MUDAR O Q EST NO DIAGRAMA DE CLASSE POIS NUM PODE SER CONTINUE*** */
	/**
	 * Mtodo que permite ao usurio continuar um jogo j iniciado
	 * anteriormente.
	 */
	public void continuing() {
		Game game = new Game(new GameSettings());
		GameScreen gs = new GameScreen(this, game);
		//this.main.setGameScreen(gs);
		this.main.getDisplay().setCurrent(gs);
	}

	/**
	 * Mtodo que mostra na tela as configuraes atuais do jogo, permitindo ao
	 * usurio modific-las.
	 */
	public void showSettingsScreen() {

		SettingsScreen settings = new SettingsScreen(this);
		this.main.getDisplay().setCurrent(settings);

	}

	/**
	 * Mtodo que mostra na tela as informaes de ajuda do jogo, atravs da
	 * seleo da opo "help" do menu.
	 */
	public void showHelpScreen() {
		HelpScreen help = new HelpScreen(this);
		this.main.getDisplay().setCurrent(help);
	}

	/**
	 * Mtodo que mostra na tela o placar de recordes do jogo, atravs da
	 * seleo da opo "records" do menu.
	 */
	public void showRecordsScreen() {

		RecordsScreen records = new RecordsScreen(this);

		//records.getRecords().initialize();

		this.main.getDisplay().setCurrent(records);
	}

	/**
	 * Mtodo que mostra na tela os crditos do sistema, atravs da seleo da
	 * opo "credits" do menu.
	 */
	public void showCreditsScreen() {

		CreditsScreen credits = new CreditsScreen(this);
		this.main.getDisplay().setCurrent(credits);

	}

	/**
	 * Mtodo que mostra na tela o nvel do jogo, permitindo ao usurio
	 * modific-lo.
	 */
	/*
	 * public void showLevelScreen() { }
	 */

	/**
	 * Mtodo que salva as modificaes da configurao do jogo.
	 */
	/*
	 * public void saveSettings() { }
	 */

	/**
	 * @return Returns the main.
	 */
	public Labyrinth getMain() {
		return main;
	}
	
	public void initGameSettings(){
		this.gs = null;
		System.gc();
		this.gs = new GameSettings();
	}
}